====================
The Telemetry object
====================
The telemetry object which is an instance of the ``Telemetry`` class forms the
core of this package as it is used to capture relevant telemetry data during
the data retrieval and processing. The class provides many instance methods to
add telemetry data, counters and errors. Also a save method is provided to
persist the telemetry data in the database of choice (:doc:`see storage class page </storage class>` .
